@@ -21,6 +21,7 @@ my $arg = join(' ', @ARGV);
 my $new_x;
 my $new_y;
 my $F;
+my $FR;
 my $dev = 0;
 my $psize = 1;
 
@@ -46,11 +47,21 @@ closedir($DIR);
 
 our @IMAGES;
 our @SMALL_IMAGES;
+our $DB = 0;
+our $STAMP = sprintf('%.1',time);
 
 if (defined($new_x)) {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x, 'SIMULATED_Y' => $new_y, 'SPLASH' => 0);
+    $FR = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x, 'SIMULATED_Y' => $new_y, 'SPLASH' => 0);
 } else {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SPLASH' => 0);
+    $FR = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SPLASH' => 0);
+}
+
+my $sinfo = $FR->screen_dimensions;
+if ($sinfo->{'bits_per_pixel'} == 16) {
+    $F = Graphics::Framebuffer->new('FB_DEVICE' => 'virtual', 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SPLASH' => 0, 'VXRES' => $sinfo->{'width'}, 'VYRES' => $sinfo->{'height'}, 'COLOR_ORDER' => $sinfo->{'color_order'});
+    $DB = 1;
+} else {
+    $F = $FR;
 }
 
 my $screen_width  = $F->{'XRES'};
@@ -98,6 +109,7 @@ foreach my $file (@files) {
     push(@SMALL_IMAGES, $image) if (defined($image));
     $BW = scalar(@IMAGES) - 1 if ($file =~ /wolf/i);
 } ## end foreach my $file (@files)
+
 $SIG{'QUIT'} = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
 $SIG{'INT'}  = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
 $F->wait_for_console(!$rpi);
@@ -105,6 +117,7 @@ $F->cls('OFF');
 $F->splash($VERSION);
 
 sleep 1;
+# $F->acceleration(0);
 # if (0) {
 color_mapping();
 plotting();
@@ -165,12 +178,17 @@ blit_move();
 rotate();
 flipping();
 monochrome();
-or_drawing();
-xor_drawing();
-and_drawing();
-alpha_drawing();
-mask_drawing();
-unmask_drawing();
+foreach my $m (1 .. 10) {
+    if ($m == MASK_MODE) {
+        mask_drawing();
+    } elsif ($m == UNMASK_MODE) {
+        unmask_drawing();
+    } elsif ($m == ALPHA_MODE) {
+        alpha_drawing();
+    } else {
+        mode_drawing($m);
+    }
+}
 animated();
 
 $F->clip_reset();
@@ -198,6 +216,7 @@ sub color_mapping {
             }
         }
     );
+    update();
     sleep $factor / 2;
     
     $F->rbox(
@@ -217,6 +236,7 @@ sub color_mapping {
             }
         }
     );
+    update();
     sleep $factor / 2 unless ($rpi);
     
     my $image = $F->load_image(
@@ -230,6 +250,7 @@ sub color_mapping {
         }
     );
     $F->blit_write($image);
+    update();
     sleep $factor;
 } ## end sub color_mapping
 
@@ -243,6 +264,7 @@ sub plotting {
         my $y = int(rand($screen_height));
         $F->set_color({ 'alpha' => 255, 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->plot({ 'x' => $x, 'y' => $y, 'pixel_size' => $psize });
+        update();
     } ## end while (time < $s)
 } ## end sub plotting
 
@@ -258,7 +280,7 @@ sub lines {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->line({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'antialiased' => $aa, 'pixel_size' => $psize });
-#        sleep 1 if ($aa);
+        update();
     }
 } ## end sub lines
 
@@ -278,6 +300,7 @@ sub angle_lines {
         $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => int($F->{'H_CLIP'} / 2), 'angle' => $angle, 'antialiased' => $aa, 'pixel_size' => $psize });
 	    $angle += 7;
         $angle -= 360 if ($angle >= 360);
+        update();
     } ## end while (time < $s)
 } ## end sub angle_lines
 
@@ -289,6 +312,7 @@ sub boxes {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'pixel_size' => $psize });
+        update();
     }
 } ## end sub boxes
 
@@ -300,6 +324,7 @@ sub filled_boxes {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'filled' => 1 });
+        update();
     }
 } ## end sub filled_boxes
 
@@ -337,6 +362,7 @@ sub gradient_boxes {
                 }
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub vertical_gradient_boxes
 
@@ -365,6 +391,7 @@ sub hatch_filled_boxes {
                 'hatch'  => $HATCHES[int(rand(scalar(@HATCHES)))]
             }
         );
+        update();
     } ## end while (time < $s)
     $F->attribute_reset();
 } ## end sub hatch_filled_boxes
@@ -386,6 +413,7 @@ sub texture_filled_boxes {
                 'texture' => $image
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub texture_filled_boxes
 
@@ -397,6 +425,7 @@ sub rounded_boxes {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'pixel_size' => $psize });
+        update();
     }
 } ## end sub rounded_boxes
 
@@ -408,6 +437,7 @@ sub filled_rounded_boxes {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'filled' => 1 });
+        update();
     }
 } ## end sub filled_rounded_boxes
 
@@ -420,6 +450,7 @@ sub hatch_filled_rounded_boxes {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'radius' => 4 + rand($XX / 16), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
+        update();
     }
     $F->attribute_reset();
 } ## end sub hatch_filled_rounded_boxes
@@ -461,6 +492,7 @@ sub gradient_rounded_boxes {
                 }
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub vertical_gradient_rounded_boxes
 
@@ -482,6 +514,7 @@ sub texture_filled_rounded_boxes {
                 'texture' => $image
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub texture_filled_rounded_boxes
 
@@ -493,6 +526,7 @@ sub circles {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'pixel_size' => $psize });
+        update();
     }
 } ## end sub circles
 
@@ -504,6 +538,7 @@ sub filled_circles {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'filled' => 1 });
+        update();
     }
 } ## end sub filled_circles
 
@@ -516,6 +551,7 @@ sub hatch_filled_circles {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
+        update();
     }
     $F->attribute_reset();
 } ## end sub hatch_filled_circles
@@ -551,6 +587,7 @@ sub gradient_circles {
                 }
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub vertical_gradient_circles
 
@@ -570,6 +607,7 @@ sub texture_filled_circles {
                 'texture' => $image
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub texture_filled_circles
 
@@ -581,6 +619,7 @@ sub arcs {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'pixel_size' => $psize });
+        update();
     }
 } ## end sub arcs
 
@@ -591,6 +630,7 @@ sub poly_arcs {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->poly_arc({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'pixel_size' => $psize });
+        update();
     }
 } ## end sub poly_arcs
 
@@ -598,10 +638,11 @@ sub filled_pies {
     
     print_it($F, 'Filled Pie Test');
 
-    my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
+    my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->filled_pie({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360) });
+        update();
     }
 } ## end sub filled_pies
 
@@ -614,6 +655,7 @@ sub hatch_filled_pies {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->filled_pie({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360), 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
+        update();
     }
     $F->attribute_reset();
 } ## end sub hatch_filled_pies
@@ -648,6 +690,7 @@ sub gradient_pies {
                 }
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub vertical_gradient_pies
 
@@ -672,6 +715,7 @@ sub texture_filled_pies {
                 'texture'       => $image,
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub texture_filled_pies
 
@@ -683,6 +727,7 @@ sub ellipses {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'pixel_size' => $psize });
+        update();
     }
 } ## end sub ellipses
 
@@ -694,6 +739,7 @@ sub filled_ellipses {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)), 'alpha' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'filled' => 1 });
+        update();
     }
 } ## end sub filled_ellipses
 
@@ -706,6 +752,7 @@ sub hatch_filled_ellipses {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->set_b_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->ellipse({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xradius' => rand($center_x), 'yradius' => rand($center_y), 'filled' => 1, 'hatch' => $HATCHES[int(rand(scalar(@HATCHES)))] });
+        update();
     }
     $F->attribute_reset();
 } ## end sub hatch_filled_ellipses
@@ -739,6 +786,7 @@ sub gradient_ellipses {
                 }
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub vertical_gradient_ellipses
 
@@ -759,6 +807,7 @@ sub texture_filled_ellipses {
                 'texture' => $image
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub texture_filled_ellipses
 
@@ -786,6 +835,7 @@ sub polygons {
                 'pixel_size'  => $psize
             }
         );
+        update();
     }
 } ## end sub polygons
 
@@ -807,6 +857,7 @@ sub filled_polygons {
                 'filled'      => 1,
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub filled_polygons
 
@@ -831,6 +882,7 @@ sub hatch_filled_polygons {
                 'hatch'       => $HATCHES[int(rand(scalar(@HATCHES)))]
             }
         );
+        update();
     } ## end while (time < $s)
     $F->attribute_reset();
 } ## end sub hatch_filled_polygons
@@ -865,6 +917,7 @@ sub gradient_polygons {
                 }
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub vertical_gradient_polygons
 
@@ -888,6 +941,7 @@ sub texture_filled_polygons {
                 'texture'     => $image
             }
         );
+        update();
     } ## end while (time < $s)
 } ## end sub texture_filled_polygons
 
@@ -903,6 +957,7 @@ sub beziers {
             push(@coords, int(rand($XX)), int(rand($YY)));
         }
         $F->bezier({ 'coordinates' => \@coords, 'points' => 100, 'pixel_size' => $psize });
+        update();
     } ## end while (time < $s)
 } ## end sub beziers
 
@@ -937,6 +992,7 @@ sub truetype_fonts {
             $b->{'x'} = rand($F->{'XX_CLIP'} - $b->{'pwidth'});
             $F->ttf_print($b);
         }
+        $STAMP = '';update();
     } ## end while (time < $g)
 } ## end sub truetype_fonts
 
@@ -972,6 +1028,7 @@ sub rotate_truetype_fonts {
         }
         $angle++;
         $angle = 0 if ($angle >= 360);
+        update();
     } ## end while (time < $g)
 } ## end sub rotate_truetype_fonts
 
@@ -990,21 +1047,25 @@ sub flood_fill {
 
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->circle({ 'x' => 500 * $xm, 'y' => 320 * $ym, 'radius' => 100 * $xm });
+        $STAMP = '';update();
         sleep 1 if ($F->{'ACCELERATED'});
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
 
         #        $F->plot({x=>350*$xm,y=>250*$ym,pixel_size=>10});sleep 20;
         $F->fill({ 'x' => 350 * $xm, 'y' => 250 * $ym, 'texture' => $image });
+        $STAMP = '';update();
 
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->fill({ 'x' => 960 * $xm, 'y' => 440 * $ym });
     } else {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->polygon({ 'coordinates' => [$center_x, 3, 3, $YY - 3, $center_x, $center_y, $XX - 3, $YY - 4] });
+        $STAMP = '';update();
 
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->fill({ 'x' => 3, 'y' => 3 });
     } ## end else [ if ($XX > 255) ]
+    $STAMP = '';update();
     sleep $factor if ($F->{'ACCELERATED'});
 } ## end sub flood_fill
 
@@ -1039,6 +1100,7 @@ sub color_replace_with_clipping {
             }
         );
         ($r, $g, $b) = ($R, $G, $B);
+        $STAMP = '';update();
     } ## end while (time < $s)
 } ## end sub color_replace_with_clipping
 
@@ -1073,6 +1135,7 @@ sub color_replace_no_clipping {
             }
         );
         ($r, $g, $b) = ($R, $G, $B);
+        $STAMP = '';update();
     } ## end while (time < $s)
 } ## end sub color_replace_no_clipping
 
@@ -1087,6 +1150,7 @@ sub blitting {
         $image->{'x'} = abs(rand($XX - $image->{'width'}));
         $image->{'y'} = $F->{'Y_CLIP'} + abs(rand(($YY - $F->{'Y_CLIP'}) - $image->{'height'}));
         $F->blit_write($image);
+        $STAMP = '';update();
     }
 } ## end sub blitting
 
@@ -1105,6 +1169,7 @@ sub blit_move {
         $F->blit_move({'x' => $x,'y' => $y,'width' => $w, 'height' => $h, 'x_dest' => $x + 6,'y_dest' => $y + 3});
         $x += 6;
         $y += 3;
+        $STAMP = '';update();
     }
 } ## end sub blit_move
 
@@ -1146,6 +1211,7 @@ sub rotate {
             );
 
             $F->blit_write($rot);
+            $STAMP = '';update();
 
             $angle += 5;
             $angle = 0 if ($angle >= 360);
@@ -1185,6 +1251,7 @@ sub rotate {
             $angle -= 5;
             $angle = 0 if ($angle <= -360);
             $count++;
+            $STAMP = '';update();
         } ## end while (time < $s || $count...)
         last if ($F->{'BITS'} == 16);
     } ## end foreach my $p (0 .. 1)
@@ -1210,6 +1277,7 @@ sub flipping {
             $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
             print_it($F, "Testing Image Flip $dir");
             $F->blit_write($rot);
+            $STAMP = '';update();
 
             sleep .3 if (time < $zoom);
         } ## end foreach my $dir (qw(normal horizontal vertical both))
@@ -1229,6 +1297,7 @@ sub monochrome {
         $mono->{'x'} = abs(rand($XX - $mono->{'width'}));
         $mono->{'y'} = $F->{'Y_CLIP'} + abs(rand(($YY - $F->{'Y_CLIP'}) - $mono->{'height'}));
         $F->blit_write($mono);
+        $STAMP = '';update();
     }
 } ## end sub monochrome
 
@@ -1245,7 +1314,7 @@ sub animated {
         for my $count (0 .. 1) {
             
             if ($count || $XX <= 320) {
-                print_it($F, "Loading Animated Image '$info' Scaled to Full Screen", 'FFFF00FF');
+                print_it($F, "Loading Animated Image '$info' Scaled to Full Screen", 'FFFF00FF', {'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255});
                 print STDERR "\n";
                 $image = $F->load_image(
                     {
@@ -1256,7 +1325,7 @@ sub animated {
                     }
                 );
             } else {
-                print_it($F, "Loading Animated Image '$info' Native Size", 'FFFF00FF');
+                print_it($F, "Loading Animated Image '$info' Native Size", 'FFFF00FF', {'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255});
                 print STDERR "\n";
                 $image = $F->load_image(
                     {
@@ -1269,9 +1338,9 @@ sub animated {
 
             foreach my $bench (0 .. 1) {
                 if ($count || $XX <= 320) {
-                    print_it($F, $bench ? "Playing Animated Image of '$info' Fullscreen Benchmark" : "Playing Animated Image of '$info' Fullscreen",$bench ? '0066FFFF' : '00FF00FF');
+                    print_it($F, $bench ? "Playing Animated Image of '$info' Fullscreen Benchmark" : "Playing Animated Image of '$info' Fullscreen",$bench ? '0066FFFF' : 'FF00FFFF', $bench ? {'red' => 0, 'green' => 64, 'blue' => 0, 'alpha' => 255} : undef);
                 } else {
-                    print_it($F, $bench ? "Playing Animated Image of '$info' Native Size Benchmark" : "Playing Animated Image of '$info' Native Size",$bench ? '0066FFFF' : '00FF00FF');
+                    print_it($F, $bench ? "Playing Animated Image of '$info' Native Size Benchmark" : "Playing Animated Image of '$info' Native Size",$bench ? '0066FFFF' : 'FF00FFFF', $bench ? {'red' => 0, 'green' => 64, 'blue' => 0, 'alpha' => 255} : undef );
                 }
                 if (defined($image)) {
                     $F->cls();
@@ -1288,6 +1357,7 @@ sub animated {
                             }
                             my $begin = time;
                             $F->blit_write($image->[$frame]);
+                            $STAMP = '';update();
                             my $delay = (($image->[$frame]->{'tags'}->{'gif_delay'} * .01)) - (time - $begin);
                             if ($delay > 0 && !$bench) {
                                 sleep $delay;
@@ -1309,23 +1379,31 @@ sub animated {
     } ## end foreach my $info (@list)
 } ## end sub animated
 
-sub or_drawing {
-    
-    print_it($F, 'Testing OR Drawing Mode');
+sub mode_drawing {
+    my $mode = shift;
+    my @modes = qw( NORMAL XOR OR AND MASK UNMASK ALPHA ADD SUBTRACT MULTIPLY DIVIDE );
+    print_it($F, 'Testing ' . $modes[$mode] . ' Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
     my $image2;
     do {
         $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
     } until ($image2->{'image'} ne $image->{'image'});
 
+    if ($mode == AND_MODE) {
+        $F->set_b_color({ 'red' => 255, 'green' => 255, 'blue' => 255 });
+        $F->cls();
+    }
+
     $F->normal_mode();
     $F->blit_write($image);
+    $STAMP = '';update();
     sleep 2;
 
-    $F->or_mode();
+    $F->{'DRAW_MODE'} = $mode;
     $F->blit_write($image2);
+    $STAMP = '';update();
     sleep 2;
-    
+
     my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
     my $mid  = int($XX / 2);
 
@@ -1337,73 +1415,10 @@ sub or_drawing {
 
     $F->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
     $F->circle({ 'x' => $mid + ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
+    $STAMP = '';update();
     sleep $factor;
 } ## end sub or_drawing
 
-sub xor_drawing {
-            
-    print_it($F, 'Testing XOR Drawing Mode');
-    my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
-    my $image2;
-    do {
-        $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
-    } until ($image2->{'image'} ne $image->{'image'});
-
-    $F->normal_mode();
-    $F->blit_write($image);
-    sleep 2;
-    
-    $F->xor_mode();
-    $F->blit_write($image2);
-    sleep 2;
-    
-
-    $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255 });
-    $F->rbox({ 'x' => 0, 'y' => 0, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
-
-    $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 255 });
-    $F->rbox({ 'x' => $XX / 4, 'y' => $YY / 4, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
-
-    $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0 });
-    $F->rbox({ 'x' => ($XX / 2), 'y' => ($YY / 2), 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
-    sleep $factor;
-} ## end sub xor_drawing
-
-sub and_drawing {
-    
-    print_it($F, 'Testing AND Drawing Mode');
-    my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
-    my $image2;
-    do {
-        $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
-    } until ($image2->{'image'} ne $image->{'image'});
-
-    $F->set_b_color({ 'red' => 255, 'green' => 255, 'blue' => 255 });
-    
-    $F->normal_mode();
-    $F->cls();
-    $F->blit_write($image);
-    sleep 2;
-
-    $F->and_mode();
-    $F->blit_write($image2);
-    sleep 2;
-    
-    my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
-    my $mid  = int($XX / 2);
-
-    $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
-    $F->circle({ 'x' => $mid - ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
-
-    $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
-    $F->circle({ 'x' => $mid, 'y' => $F->{'Y_CLIP'} + $size, 'radius' => $size, 'filled' => 1 });
-
-    $F->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
-    $F->circle({ 'x' => $mid + ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
-    $F->set_b_color({ 'red' => 0, 'green' => 0, 'blue' => 0 });
-    sleep $factor;
-} ## end sub and_drawing
-
 sub alpha_drawing {
     
     $F->attribute_reset();
@@ -1419,10 +1434,12 @@ sub alpha_drawing {
 
     $F->normal_mode();
     $F->blit_write($image);
+    $STAMP = '';update();
     sleep 2;
-    
+
     $F->alpha_mode();
     $F->blit_write($image2);
+    $STAMP = '';update();
     sleep 2;
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255, 'alpha' => int(rand(256)) });
@@ -1433,6 +1450,7 @@ sub alpha_drawing {
 
     $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0, 'alpha' => int(rand(256)) });
     $F->rbox({ 'x' => ($XX / 2), 'y' => ($YY / 2), 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
+    $STAMP = '';update();
     sleep $factor;
 } ## end sub alpha_drawing
 
@@ -1451,8 +1469,10 @@ sub mask_drawing {
     $F->normal_mode();
     $F->blit_write($image1);
     $F->mask_mode();
+    $STAMP = '';update();
     sleep .3;
     $F->blit_write($image2);
+    $STAMP = '';update();
     sleep $factor;
 } ## end sub mask_drawing
 
@@ -1469,9 +1489,10 @@ sub unmask_drawing {
     $F->normal_mode();
     $F->blit_write($image1);
     $F->unmask_mode();
+    $STAMP = '';update();
     sleep .3;
     $F->blit_write($image2);
-
+    $STAMP = '';update();
     sleep $factor;
 } ## end sub unmask_drawing
 
@@ -1479,9 +1500,11 @@ sub print_it {
     my $fb      = shift;
     my $message = shift;
     my $color   = shift || 'FFFF00FF';
+    my $bgcolor = shift || {'red' => 0, 'green' => 0, 'blue' => 0, 'alpha' => 0};
 
     $fb->normal_mode();
     $fb->clip_reset();
+    $fb->set_b_color($bgcolor);
     $fb->cls();
     unless ($XX <= 320) {
         $fb->or_mode();
@@ -1506,8 +1529,17 @@ sub print_it {
         system('clear');
         print STDERR "$message\n";
     }
+    $STAMP = '';update();
 } ## end sub print_it
 
+sub update {
+    my $now = sprintf('%.1f',time);
+    if ($now ne $STAMP) {
+        $FR->blit_flip($F) if ($DB);
+        $STAMP = $now;
+    }
+}
+
 __END__
 
 =head1 NAME
