@@ -12,7 +12,7 @@ use constant {
 use List::Util qw(min max);
 
 BEGIN {
-    our $VERSION = 1.00;
+    our $VERSION = 1.01;
 }
 
 sub _perl_logo {
@@ -26,9 +26,9 @@ sub _perl_logo {
     $self->ellipse(
         {
             'x'       => 965 * $hf,
-            'y'       => 70  * $vf,
+            'y'       => 70 * $vf,
             'xradius' => 140 * $hf,
-            'yradius' => 65  * $vf,
+            'yradius' => 65 * $vf,
             'filled'  => TRUE
         }
     );
@@ -36,9 +36,9 @@ sub _perl_logo {
     $self->ellipse(
         {
             'x'       => 960 * $hf,
-            'y'       => 65  * $vf,
+            'y'       => 65 * $vf,
             'xradius' => 140 * $hf,
-            'yradius' => 65  * $vf,
+            'yradius' => 65 * $vf,
             'filled'  => TRUE
         }
     );
@@ -48,7 +48,7 @@ sub _perl_logo {
         $self->ttf_print(
             {
                 'bounding_box' => TRUE,
-                'y'            => 126 * $vf, # 85 * $vf,
+                'y'            => 126 * $vf,                                     # 85 * $vf,
                 'height'       => 80 * $vf,
                 'wscale'       => 1,
                 'color'        => '0040FFFF',
@@ -82,193 +82,42 @@ sub splash {
 
     $self->cls();
     $self->clip_reset();
+    $self->normal_mode();
 
-    if (($W <= 320) || ($H <= 240)) {
+    if (1 && (($W <= 320) || ($H <= 240))) {
         $hf = $W / 320;
         $vf = $H / 240;
-        $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 64 });
-        $self->polygon(
+
+        #        $self->set_color({ 'red' => 128, 'green' => 0, 'blue' => 0 });
+        $self->rbox(
             {
-                'coordinates' => [
-                    (67.5  * $hf) + $X, (16.875  * $vf) + $Y,
-                    (3.325 * $hf) + $X, (178.125 * $vf) + $Y,
-                    (267.5 * $hf) + $X, (238.125 * $vf) + $Y,
-                    (315   * $hf) + $X, (2.5     * $vf) + $Y
-                ],
-                'filled'      => TRUE,
-                'gradient'    => {
+                'x'        => $X,
+                'y'        => $Y,
+                'width'    => 320 * $hf,
+                'height'   => 240 * $vf,
+                'radius'   => 10,
+                'filled'   => TRUE,
+                'gradient' => {
                     'start' => {
                         'red'   => 0,
                         'green' => 0,
-                        'blue'  => 16
+                        'blue'  => 128
                     },
                     'end' => {
-                        'red'   => 0,
+                        'red'   => 128,
                         'green' => 0,
-                        'blue'  => 200
-                    }
-                }
-            }
-        );
-        $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 1 });
-        $self->rbox(
-            {
-                'x'      => (25     * $hf) + $X,
-                'y'      => (28.125 * $vf) + $Y,
-                'width'  => 277.5   * $hf,
-                'height' => 185.625 * $vf,
-                'radius' => 4,
-                'filled' => TRUE
-            }
-        );
-
-        $self->set_color({ 'red' => 128, 'green' => 0, 'blue' => 0 });
-        $self->rbox(
-            {
-                'x'      => (20     * $hf) + $X,
-                'y'      => (24.375 * $vf) + $Y,
-                'width'  => 277.5   * $hf,
-                'height' => 185.625 * $vf,
-                'radius' => 4,
-                'filled' => TRUE
-            }
-        );
-        $self->set_color({ 'red' => 64, 'green' => 0, 'blue' => 0 });
-        $self->circle(
-            {
-                'x'      => (37.5 * max($vf, $hf)) + $X,
-                'y'      => (36   * max($vf, $hf)) + $Y,
-                'radius' => 35    * max($vf, $hf),
-                'filled' => TRUE
-            }
-        );
-
-        $self->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0 });
-        $self->circle(
-            {
-                'x'        => (35 * max($hf, $vf)) + $X,
-                'y'        => (36 * max($vf, $hf)) + $Y,
-                'radius'   => 35  * max($hf, $vf),
-                'filled'   => TRUE,
-                'gradient' => {
-                    'direction' => 'horizontal',
-                    'start'     => {
-                        'red'   => 255,
-                        'green' => 0,
-                        'blue'  => 0
-                    },
-                    'end' => {
-                        'red'   => 255,
-                        'green' => 255,
                         'blue'  => 0
                     }
                 }
             }
         );
-        my $color;
         $self->or_mode();
-
-        # G
-        if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $color = '0000FFFF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $color = '0000FFFF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $color = 'FF0000FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $color = 'FF0000FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $color = '00FF00FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $color = '00FF00FF';
-        }
-        $self->ttf_print(
-            $self->ttf_print(
-                {
-                    'bounding_box' => TRUE,
-                    'x'            => (75  * $hf) + $X,
-                    'y'            => (70  * $vf) + $Y,
-                    'height'       => 37.5 * $vf,
-                    'wscale'       => 2,
-                    'color'        => $color,
-                    'text'         => 'G',
-                    'face'         => $bold,
-                    'bounding_box' => TRUE,
-                    'center'       => 0,
-                    'antialias'    => FALSE
-                }
-            )
-        );
-
-        # F
-        if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $color = '00FF00FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $color = 'FF0000FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $color = '00FF00FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $color = '0000FFFF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $color = 'FF0000FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $color = '0000FFFF';
-        }
-        $self->ttf_print(
-            $self->ttf_print(
-                {
-                    'bounding_box' => TRUE,
-                    'x'            => 0,
-                    'y'            => (70  * $vf) + $Y,
-                    'height'       => 37.5 * $vf,
-                    'wscale'       => 2,
-                    'color'        => $color,
-                    'text'         => 'F',
-                    'face'         => $bold,
-                    'bounding_box' => TRUE,
-                    'center'       => $self->{'CENTER_X'},
-                    'antialias'    => FALSE
-                }
-            )
-        );
-
-        # B
-        if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $color = 'FF0000FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $color = '00FF00FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $color = '0000FFFF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $color = '00FF00FF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $color = '0000FFFF';
-        } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $color = 'FF0000FF';
-        }
-        $self->ttf_print(
-            $self->ttf_print(
-                {
-                    'bounding_box' => TRUE,
-                    'x'            => (190 * $hf) + $X,
-                    'y'            => (70  * $vf) + $Y,
-                    'height'       => 37.5 * $vf,
-                    'wscale'       => 2,
-                    'color'        => $color,
-                    'face'         => $bold,
-                    'text'         => 'B',
-                    'bounding_box' => TRUE,
-                    'center'       => 0,
-                    'antialias'    => FALSE
-                }
-            )
-        );
         my $gfb = $self->ttf_print(
             {
                 'bounding_box' => TRUE,
                 'x'            => 0,
-                'y'            => (130 * $vf) + $Y,
-                'height'       => 42   * $vf,
+                'y'            => (68 * $vf) + $Y,
+                'height'       => 52 * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFF00FF',
                 'text'         => 'Graphics-Framebuffer',
@@ -277,9 +126,9 @@ sub splash {
                 'antialias'    => FALSE
             }
         );
-        if ($gfb->{'pwidth'} > int(270 * $hf)) {
+        if ($gfb->{'pwidth'} > int(304 * $hf)) {
             $gfb->{'bounding_box'} = TRUE;
-            $gfb->{'wscale'}       = int(270 * $hf) / $gfb->{'pwidth'};
+            $gfb->{'wscale'}       = int(304 * $hf) / $gfb->{'pwidth'};
             $gfb                   = $self->ttf_print($gfb);
         }
         $self->ttf_print($gfb);
@@ -288,53 +137,76 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => 0,
-                    'y'            => (170 * $vf) + $Y,
-                    'height'       => 38   * $vf,
+                    'y'            => (116 * $vf) + $Y,
+                    'height'       => 40 * $vf,
                     'wscale'       => 1,
                     'color'        => 'FFFFFFFF',
-                    'text'         => sprintf('VERSION %.02f', $version),
+                    'text'         => sprintf('%dx%d-%02d', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}),
                     'bounding_box' => TRUE,
                     'center'       => $self->{'CENTER_X'},
-                    'antialias'    => FALSE
+                    'antialias'    => FALSE,
                 }
             )
         );
-        my @fonts   = grep(!/atari|mono|light|italic|bold|black/i, grep(/condensed/i, (keys %{ $self->{'FONTS'} })));
-        my $font    = $fonts[int(rand(scalar(@fonts)))];
-        my $scaleit = $self->ttf_print(
+        $self->ttf_print(
+            $self->ttf_print(
+                {
+                    'bounding_box' => TRUE,
+                    'x'            => 0,
+                    'y'            => (149 * $vf) + $Y,
+                    'height'       => 34 * $vf,
+                    'wscale'       => 1,
+                    'color'        => 'FFFFFFFF',
+                    'text'         => 'ON',
+                    'bounding_box' => TRUE,
+                    'center'       => $self->{'CENTER_X'},
+                    'antialias'    => FALSE,
+                }
+            )
+        );
+        $self->ttf_print(
+            $self->ttf_print(
+                {
+                    'bounding_box' => TRUE,
+                    'x'            => 0,
+                    'y'            => (192 * $vf) + $Y,
+                    'height'       => 40 * $vf,
+                    'wscale'       => 1,
+                    'color'        => 'FFFFFFFF',
+                    'text'         => uc($self->{'fscreeninfo'}->{'id'} || 'Unknown GPU'),
+                    'bounding_box' => TRUE,
+                    'center'       => $self->{'CENTER_X'},
+                    'antialias'    => FALSE,
+                }
+            )
+        );
+        $gfb = $self->ttf_print(
             {
                 'bounding_box' => TRUE,
                 'x'            => 0,
-                'y'            => (220 * $vf) + $Y,
-                'height'       => 48   * $vf,
+                'y'            => (240 * $vf) + $Y,
+                'height'       => 40 * $vf,
                 'wscale'       => 1,
-                'color'        => 'FFFFFFFF',
-                'text'         => sprintf('%dx%d-%02d ON %s', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}, uc($self->{'fscreeninfo'}->{'id'} || 'Unknown GPU')),
+                'color'        => '00FF00FF',
+                'text'         => sprintf('VERSION %.02f', $version),
                 'bounding_box' => TRUE,
                 'center'       => $self->{'CENTER_X'},
-                'antialias'    => FALSE,
-                'font_path'    => $self->{'FONTS'}->{$font}->{'path'},
-                'face'         => $self->{'FONTS'}->{$font}->{'font'}
+                'antialias'    => FALSE
             }
         );
-        if ($scaleit->{'pwidth'} > int(270 * $hf)) {
-            $scaleit->{'bounding_box'} = TRUE;
-            $scaleit->{'wscale'}       = int(270 * $hf) / $scaleit->{'pwidth'};
-            $scaleit                   = $self->ttf_print($scaleit);
+        if ($gfb->{'pwidth'} > int(304 * $hf)) {
+            $gfb->{'bounding_box'} = TRUE;
+            $gfb->{'wscale'}       = int(304 * $hf) / $gfb->{'pwidth'};
+            $gfb                   = $self->ttf_print($gfb);
         }
-        $self->ttf_print($scaleit);
+        $self->ttf_print($gfb);
     } else {
 
         # Draws the main boxes
         $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 64 });
         $self->polygon(
             {
-                'coordinates' => [
-                    (400  * $hf) + $X, (80   * $vf) + $Y,
-                    (20   * $hf) + $X, (800  * $vf) + $Y,
-                    (1600 * $hf) + $X, (1078 * $vf) + $Y,
-                    (1900 * $hf) + $X, (5    * $vf) + $Y
-                ],
+                'coordinates' => [(400 * $hf) + $X, (80 * $vf) + $Y, (20 * $hf) + $X, (800 * $vf) + $Y, (1600 * $hf) + $X, (1078 * $vf) + $Y, (1900 * $hf) + $X, (5 * $vf) + $Y],
                 'filled'      => TRUE,
                 'gradient'    => {
                     'start' => {
@@ -357,8 +229,8 @@ sub splash {
                 'x'      => (160 * $hf) + $X,
                 'y'      => (160 * $vf) + $Y,
                 'width'  => 1620 * $hf,
-                'height' => 780  * $vf,
-                'radius' => 15   * min($hf, $vf),
+                'height' => 780 * $vf,
+                'radius' => 15 * min($hf, $vf),
                 'filled' => TRUE
             }
         );
@@ -369,8 +241,8 @@ sub splash {
                 'x'      => (150 * $hf) + $X,
                 'y'      => (150 * $vf) + $Y,
                 'width'  => 1620 * $hf,
-                'height' => 780  * $vf,
-                'radius' => 15   * min($hf, $vf),
+                'height' => 780 * $vf,
+                'radius' => 15 * min($hf, $vf),
                 'filled' => TRUE
             }
         );
@@ -381,7 +253,7 @@ sub splash {
             {
                 'x'      => (207 * $hf) + $X,
                 'y'      => (207 * $vf) + $Y,
-                'radius' => 199  * min($vf, $hf),
+                'radius' => 199 * min($vf, $hf),
                 'filled' => TRUE
             }
         );
@@ -391,7 +263,7 @@ sub splash {
             {
                 'x'        => (200 * $hf) + $X,
                 'y'        => (200 * $vf) + $Y,
-                'radius'   => 199  * min($hf, $vf),
+                'radius'   => 199 * min($hf, $vf),
                 'filled'   => TRUE,
                 'gradient' => {
                     'direction' => 'horizontal',
@@ -415,7 +287,7 @@ sub splash {
             {
                 'x'             => (102 * $hf) + $X,
                 'y'             => (202 * $vf) + $Y,
-                'radius'        => 52   * $vf,
+                'radius'        => 52 * $vf,
                 'start_degrees' => 340,
                 'end_degrees'   => 270,
                 'granularity'   => 0.05
@@ -425,18 +297,7 @@ sub splash {
         # F
         $self->polygon(
             {
-                'coordinates' => [
-                    (162 * $hf) + $X, (252 * $vf) + $Y,
-                    (162 * $hf) + $X, (152 * $vf) + $Y,
-                    (262 * $hf) + $X, (152 * $vf) + $Y,
-                    (242 * $hf) + $X, (172 * $vf) + $Y,
-                    (182 * $hf) + $X, (172 * $vf) + $Y,
-                    (182 * $hf) + $X, (192 * $vf) + $Y,
-                    (222 * $hf) + $X, (192 * $vf) + $Y,
-                    (202 * $hf) + $X, (212 * $vf) + $Y,
-                    (182 * $hf) + $X, (212 * $vf) + $Y,
-                    (182 * $hf) + $X, (232 * $vf) + $Y
-                ],
+                'coordinates' => [(162 * $hf) + $X, (252 * $vf) + $Y, (162 * $hf) + $X, (152 * $vf) + $Y, (262 * $hf) + $X, (152 * $vf) + $Y, (242 * $hf) + $X, (172 * $vf) + $Y, (182 * $hf) + $X, (172 * $vf) + $Y, (182 * $hf) + $X, (192 * $vf) + $Y, (222 * $hf) + $X, (192 * $vf) + $Y, (202 * $hf) + $X, (212 * $vf) + $Y, (182 * $hf) + $X, (212 * $vf) + $Y, (182 * $hf) + $X, (232 * $vf) + $Y],
                 'filled'      => TRUE,
                 'pixel_size'  => 1
             }
@@ -445,12 +306,7 @@ sub splash {
         # B
         $self->polygon(
             {
-                'coordinates' => [
-                    (272 * $hf) + $X, (252 * $vf) + $Y,
-                    (272 * $hf) + $X, (152 * $vf) + $Y,
-                    (322 * $hf) + $X, (152 * $vf) + $Y,
-                    (322 * $hf) + $X, (252 * $vf) + $Y
-                ],
+                'coordinates' => [(272 * $hf) + $X, (252 * $vf) + $Y, (272 * $hf) + $X, (152 * $vf) + $Y, (322 * $hf) + $X, (152 * $vf) + $Y, (322 * $hf) + $X, (252 * $vf) + $Y],
                 'filled'      => TRUE,
                 'pixel_size'  => 1
             }
@@ -459,7 +315,7 @@ sub splash {
             {
                 'x'      => (322 * $hf) + $X,
                 'y'      => (177 * $vf) + $Y,
-                'radius' => 25   * $vf,
+                'radius' => 25 * $vf,
                 'filled' => TRUE
             }
         );
@@ -467,7 +323,7 @@ sub splash {
             {
                 'x'      => (322 * $hf) + $X,
                 'y'      => (227 * $vf) + $Y,
-                'radius' => 25   * $vf,
+                'radius' => 25 * $vf,
                 'filled' => TRUE
             }
         );
@@ -491,7 +347,7 @@ sub splash {
             {
                 'x'             => (100 * $hf) + $X,
                 'y'             => (200 * $vf) + $Y,
-                'radius'        => 52   * $vf,
+                'radius'        => 52 * $vf,
                 'start_degrees' => 340,
                 'end_degrees'   => 270,
                 'granularity'   => 0.05
@@ -536,12 +392,7 @@ sub splash {
         }
         $self->polygon(
             {
-                'coordinates' => [
-                    (270 * $hf) + $X, (250 * $vf) + $Y,
-                    (270 * $hf) + $X, (150 * $vf) + $Y,
-                    (320 * $hf) + $X, (150 * $vf) + $Y,
-                    (320 * $hf) + $X, (250 * $vf) + $Y
-                ],
+                'coordinates' => [(270 * $hf) + $X, (250 * $vf) + $Y, (270 * $hf) + $X, (150 * $vf) + $Y, (320 * $hf) + $X, (150 * $vf) + $Y, (320 * $hf) + $X, (250 * $vf) + $Y],
                 'filled'      => TRUE,
                 'pixel_size'  => 1
             }
@@ -550,7 +401,7 @@ sub splash {
             {
                 'x'      => (320 * $hf) + $X,
                 'y'      => (175 * $vf) + $Y,
-                'radius' => 25   * $vf,
+                'radius' => 25 * $vf,
                 'filled' => TRUE
             }
         );
@@ -558,28 +409,28 @@ sub splash {
             {
                 'x'      => (320 * $hf) + $X,
                 'y'      => (225 * $vf) + $Y,
-                'radius' => 25   * $vf,
+                'radius' => 25 * $vf,
                 'filled' => TRUE
             }
         );
         $self->set_color({ 'red' => 32, 'green' => 0, 'blue' => 0 });
         $self->rbox(
             {
-                'x'      => (478  * $hf) + $X,
-                'y'      => (208  * $vf) + $Y,
+                'x'      => (478 * $hf) + $X,
+                'y'      => (208 * $vf) + $Y,
                 'width'  => (1230 * $hf),
-                'height' => (150  * $vf),
-                'radius' => 20    * $vf,
+                'height' => (150 * $vf),
+                'radius' => 20 * $vf,
                 'filled' => TRUE,
             }
         );
         $self->rbox(
             {
-                'x'        => (470  * $hf) + $X,
-                'y'        => (200  * $vf) + $Y,
+                'x'        => (470 * $hf) + $X,
+                'y'        => (200 * $vf) + $Y,
                 'width'    => (1230 * $hf),
-                'height'   => (150  * $vf),
-                'radius'   => 20    * $vf,
+                'height'   => (150 * $vf),
+                'radius'   => 20 * $vf,
                 'filled'   => TRUE,
                 'gradient' => {
                     'start' => {
@@ -604,7 +455,7 @@ sub splash {
                         'bounding_box' => TRUE,
                         'x'            => (510 * $hf) + $X,
                         'y'            => (351 * $vf) + $Y,
-                        'height'       => 110  * $vf,
+                        'height'       => 110 * $vf,
                         'wscale'       => 1.5,
                         'color'        => '00FFFFFF',
                         'text'         => 'Accelerated',
@@ -621,7 +472,7 @@ sub splash {
                     'bounding_box' => TRUE,
                     'x'            => 0,
                     'y'            => (641 * $vf) + $Y,
-                    'height'       => 200  * $vf,
+                    'height'       => 200 * $vf,
                     'wscale'       => 1,
                     'color'        => '221100FF',
                     'text'         => 'Graphics-Framebuffer',
@@ -645,7 +496,7 @@ sub splash {
                 'bounding_box' => TRUE,
                 'x'            => 0,
                 'y'            => (641 * $vf) + $Y,
-                'height'       => 200  * $vf,
+                'height'       => 200 * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFF00FF',
                 'text'         => 'Graphics-Framebuffer',
@@ -666,7 +517,7 @@ sub splash {
                 'bounding_box' => TRUE,
                 'x'            => 0,
                 'y'            => (651 * $vf) + $Y,
-                'height'       => 50   * $vf,
+                'height'       => 50 * $vf,
                 'wscale'       => 1,
                 'color'        => '00EE00FF',
                 'text'         => 'by Richard Kelsch',
@@ -684,7 +535,7 @@ sub splash {
                     'bounding_box' => TRUE,
                     'x'            => 0,
                     'y'            => (771 * $vf) + $Y,
-                    'height'       => 120  * $vf,
+                    'height'       => 120 * $vf,
                     'wscale'       => 1,
                     'color'        => 'FFFFFFFF',
                     'text'         => sprintf('Version %.02f', $version),
@@ -699,7 +550,7 @@ sub splash {
                 'bounding_box' => TRUE,
                 'x'            => 0,
                 'y'            => (901 * $vf) + $Y,
-                'height'       => 120  * $vf,
+                'height'       => 120 * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFFFFFF',
                 'text'         => sprintf('%dx%d-%02d on %s', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}, $self->{'fscreeninfo'}->{'id'} || 'Unknown GPU'),
@@ -715,7 +566,7 @@ sub splash {
         }
         $self->ttf_print($scaleit);
         $self->_perl_logo();
-    } ## end else [ if (($W <= 320) || ($H...))]
+    } ## end else [ if (1 && (($W <= 320) ...))]
     $self->normal_mode();
 } ## end sub splash
 
